pub trait PathScalar: Sealed {
// Required method
fn path_scalar_schema() -> RefOr<Schema>;
}Expand description
Sealed trait for primitives usable as scalar Path parameters.
Implementations supply the OpenAPI schema for the parameter —
done manually (rather than via utoipa::PartialSchema) because
common scalar path types like Uuid are recognized by utoipa
only via token inspection in derives, not through a PartialSchema
impl.
Required Methods
Sourcefn path_scalar_schema() -> RefOr<Schema>
fn path_scalar_schema() -> RefOr<Schema>
OpenAPI schema to embed for this scalar parameter.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.